@@ -140,7 +140,8 @@ class objearth():
             def axis(x=0):
                 return x
             fig,ax = plt.subplots(constrained_layout=True)
-            fig.set_size_inches(8,8)
+            fig.set_size_inches(figsize)
+            ax.set_title(title)
             ax.set_xlabel(xlabel)
             ax.set_ylabel(ylabel)
             ax.imshow(DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
@@ -161,7 +162,7 @@ class objearth():
                 ymax = area[0] ; ymin = area[1]
                 xmin = area[2] ; xmax = area[3]
             real_margin_img = DataArray[ymax:ymin,xmin:xmax]
-            
+
             #plotshow
             plt.figure(figsize=(figsize))
             color_map = plt.imshow(real_margin_img,extent=[xmin,xmax,ymin,ymax])
